@@ -7,4 +7,4 @@ if [ -z "${LC_ALL+x}" ] && [ -z "${LC_CTYPE+x}" ] && \
 fi
 
 # run python
-exec /usr/bin/env PYTHONUNBUFFERED=1 "/usr/bin/python" -u -m xonsh "$@"
+exec "/usr/bin/python" -u -m xonsh "$@"
