@@ -123,6 +123,21 @@ command.
 )
 
 
+events.doc(
+    "on_lscolors_change",
+    """
+on_lscolors_change(key: str, oldvalue: Any, newvalue: Any) -> None
+
+Fires after a value in LS_COLORS changes, when a new key is added (oldvalue is None)
+or when an existing key is deleted (newvalue is None).
+LS_COLORS values must be (ANSI color) strings, None is unambiguous.
+Does not fire when the whole environment variable changes (see on_envvar_change).
+Does not fire for each value when LS_COLORS is first instantiated.
+Normal usage is to arm the event handler, then read (not modify) all existing values.
+""",
+)
+
+
 @lazyobject
 def HELP_TEMPLATE():
     return (
@@ -330,11 +345,16 @@ class LsColors(cabc.MutableMapping):
 
     def __setitem__(self, key, value):
         self._detyped = None
+        old_value = self._d.get(key, None)
         self._d[key] = value
+        if old_value != value:
+            events.on_lscolors_change.fire(key=key, oldvalue=old_value, newvalue=value)
 
     def __delitem__(self, key):
         self._detyped = None
+        old_value = self._d.get(key, None)
         del self._d[key]
+        events.on_lscolors_change.fire(key=key, oldvalue=old_value, newvalue=None)
 
     def __len__(self):
         return len(self._d)
@@ -574,6 +594,7 @@ def DEFAULT_ENSURERS():
         "SUGGEST_MAX_NUM": (is_int, int, str),
         "SUGGEST_THRESHOLD": (is_int, int, str),
         "SUPPRESS_BRANCH_TIMEOUT_MESSAGE": (is_bool, to_bool, bool_to_str),
+        "THREAD_SUBPROCS": (is_bool, to_bool, bool_to_str),
         "UPDATE_COMPLETIONS_ON_KEYPRESS": (is_bool, to_bool, bool_to_str),
         "UPDATE_OS_ENVIRON": (is_bool, to_bool, bool_to_str),
         "UPDATE_PROMPT_ON_KEYPRESS": (is_bool, to_bool, bool_to_str),
@@ -757,6 +778,7 @@ def DEFAULT_VALUES():
         "SUGGEST_COMMANDS": True,
         "SUGGEST_MAX_NUM": 5,
         "SUGGEST_THRESHOLD": 3,
+        "THREAD_SUBPROCS": True,
         "TITLE": DEFAULT_TITLE,
         "UPDATE_COMPLETIONS_ON_KEYPRESS": False,
         "UPDATE_OS_ENVIRON": False,
@@ -1072,9 +1094,10 @@ def DEFAULT_DOCS():
             default="``xonsh.environ.DEFAULT_PROMPT``",
         ),
         "PROMPT_REFRESH_INTERVAL": VarDocs(
-            "Evaluate $PROMPT, $RIGHT_PROMPT and $BOTTOM_TOOLBAR every so many seconds."
-            "This param default is zero."
-            "And if using this param, $UPDATE_COMPLETIONS_ON_KEYPRESS must be True."
+            "Interval (in seconds) to evaluate and update ``$PROMPT``, ``$RIGHT_PROMPT`` "
+            "and ``$BOTTOM_TOOLBAR``. The default is zero (no update). "
+            "NOTE: ``$UPDATE_PROMPT_ON_KEYPRESS`` must be set to ``True`` for this "
+            "variable to take effect."
         ),
         "PROMPT_TOOLKIT_COLOR_DEPTH": VarDocs(
             "The color depth used by prompt toolkit 2. Possible values are: "
@@ -1160,6 +1183,26 @@ def DEFAULT_DOCS():
             "not always happen.",
             configurable=False,
         ),
+        "THREAD_SUBPROCS": VarDocs(
+            "Whether or not to try to run subrocess mode in a Python thread, "
+            "when applicable. There are various trade-offs, which normally "
+            "affects only interactive sessions.\n\nWhen True:\n\n"
+            "* Xonsh is able capture & store the stdin, stdout, and stderr \n"
+            "  of threadable subprocesses.\n"
+            "* However, stopping threaded subprocs with ^Z (i.e. ``SIGTSTP``)\n"
+            "  is disabled as it causes deadlocked terminals.\n"
+            "  ``SIGTSTP`` may still be issued and only the physical pressing\n"
+            "  of ``Ctrl+Z`` is ignored.\n"
+            "* Threadable commands are run with ``PopenThread`` and threadable \n"
+            "  aliases are run with ``ProcProxyThread``.\n\n"
+            "When False:\n\n"
+            "* Xonsh may not be able to capture stdin, stdout, and stderr streams \n"
+            "  unless explicitly asked to do so.\n"
+            "* Stopping the thread with ``Ctrl+Z`` yields to job control.\n"
+            "* Threadable commands are run with ``Popen`` and threadable \n"
+            "  alias are run with ``ProcProxy``.\n\n"
+            "The desired effect is often up to the command, user, or use case."
+        ),
         "TITLE": VarDocs(
             "The title text for the window in which xonsh is running. Formatted "
             "in the same manner as ``$PROMPT``, see 'Customizing the Prompt' "
