@@ -15,7 +15,7 @@ from importlib.abc import MetaPathFinder, SourceLoader, Loader
 
 from xonsh.events import events
 from xonsh.execer import Execer
-from xonsh.platform import scandir
+from xonsh.platform import ON_WINDOWS, scandir
 from xonsh.lazyasd import lazyobject
 
 
@@ -108,7 +108,7 @@ class XonshImportHook(MetaPathFinder, SourceLoader):
 
     def get_data(self, path):
         """Gets the bytes for a path."""
-        raise NotImplementedError
+        raise OSError
 
     def get_code(self, fullname):
         """Gets the code object for a xonsh file."""
@@ -116,17 +116,26 @@ class XonshImportHook(MetaPathFinder, SourceLoader):
         if filename is None:
             msg = "xonsh file {0!r} could not be found".format(fullname)
             raise ImportError(msg)
-        with open(filename, "rb") as f:
-            src = f.read()
-        enc = find_source_encoding(src)
-        src = src.decode(encoding=enc)
-        src = src if src.endswith("\n") else src + "\n"
+        src = self.get_source(fullname)
         execer = self.execer
         execer.filename = filename
         ctx = {}  # dummy for modules
         code = execer.compile(src, glbs=ctx, locs=ctx)
         return code
 
+    def get_source(self, fullname):
+        if fullname is None:
+            raise ImportError("could not find fullname to module")
+        filename = self.get_filename(fullname)
+        with open(filename, "rb") as f:
+            src = f.read()
+        if ON_WINDOWS:
+            src = src.replace(b"\r\n", b"\n")
+        enc = find_source_encoding(src)
+        src = src.decode(encoding=enc)
+        src = src if src.endswith("\n") else src + "\n"
+        return src
+
 
 #
 # Import events
