@@ -2,6 +2,7 @@
 import os
 import re
 import ast
+import sys
 import json
 import shutil
 import random
@@ -14,10 +15,7 @@ import itertools
 import contextlib
 import collections
 
-try:
-    import ply
-except ImportError:
-    from xonsh.ply import ply
+from xonsh.ply import ply
 
 import xonsh.wizard as wiz
 from xonsh import __version__ as XONSH_VERSION
@@ -81,7 +79,7 @@ WIZARD_FS = """
                       {{BOLD_WHITE}}Foreign Shell Setup{{NO_COLOR}}
                       {{YELLOW}}-------------------{{NO_COLOR}}
 The xonsh shell has the ability to interface with foreign shells such
-as Bash, zsh, or fish.
+as Bash, or zsh (fish not yet implemented).
 
 For configuration, this means that xonsh can load the environment,
 aliases, and functions specified in the config files of these shells.
@@ -186,8 +184,9 @@ def _dump_xonfig_foreign_shell(path, value):
 
 def _dump_xonfig_env(path, value):
     name = os.path.basename(path.rstrip("/"))
-    ensurer = builtins.__xonsh_env__.get_ensurer(name)
-    dval = ensurer.detype(value)
+    ensurer = builtins.__xonsh__.env.get_ensurer(name)
+    dval = str(value) if ensurer.detype is None else ensurer.detype(value)
+    dval = str(value) if dval is None else dval
     return "${name} = {val!r}".format(name=name, val=dval)
 
 
@@ -285,7 +284,7 @@ ENVVAR_PROMPT = "{BOLD_GREEN}>>>{NO_COLOR} "
 
 def make_exit_message():
     """Creates a message for how to exit the wizard."""
-    shell_type = builtins.__xonsh_shell__.shell_type
+    shell_type = builtins.__xonsh__.shell.shell_type
     keyseq = "Ctrl-D" if shell_type == "readline" else "Ctrl-C"
     msg = "To exit the wizard at any time, press {BOLD_UNDERLINE_CYAN}"
     msg += keyseq + "{NO_COLOR}.\n"
@@ -295,7 +294,7 @@ def make_exit_message():
 
 def make_envvar(name):
     """Makes a StoreNonEmpty node for an environment variable."""
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     vd = env.get_docs(name)
     if not vd.configurable:
         return
@@ -341,7 +340,7 @@ def _make_flat_wiz(kidfunc, *args):
 
 def make_env_wiz():
     """Makes an environment variable wizard."""
-    w = _make_flat_wiz(make_envvar, sorted(builtins.__xonsh_env__._docs.keys()))
+    w = _make_flat_wiz(make_envvar, sorted(builtins.__xonsh__.env._docs.keys()))
     return w
 
 
@@ -444,8 +443,8 @@ def make_xonfig_wizard(default_file=None, confirm=False, no_wizard_file=None):
 
 
 def _wizard(ns):
-    env = builtins.__xonsh_env__
-    shell = builtins.__xonsh_shell__.shell
+    env = builtins.__xonsh__.env
+    shell = builtins.__xonsh__.shell.shell
     fname = env.get("XONSHRC")[-1] if ns.file is None else ns.file
     no_wiz = os.path.join(env.get("XONSH_CONFIG_DIR"), "no-wizard")
     w = make_xonfig_wizard(
@@ -492,11 +491,7 @@ def _xonfig_format_json(data):
 
 
 def _info(ns):
-    env = builtins.__xonsh_env__
-    try:
-        ply.__version__ = ply.__version__
-    except AttributeError:
-        ply.__version__ = "3.8"
+    env = builtins.__xonsh__.env
     data = [("xonsh", XONSH_VERSION)]
     hash_, date_ = githash()
     if hash_:
@@ -534,7 +529,7 @@ def _info(ns):
 
 
 def _styles(ns):
-    env = builtins.__xonsh_env__
+    env = builtins.__xonsh__.env
     curr = env.get("XONSH_COLOR_STYLE")
     styles = sorted(color_style_names())
     if ns.json:
@@ -598,13 +593,13 @@ def _tok_colors(cmap, cols):
 def _colors(args):
     columns, _ = shutil.get_terminal_size()
     columns -= int(ON_WINDOWS)
-    style_stash = builtins.__xonsh_env__["XONSH_COLOR_STYLE"]
+    style_stash = builtins.__xonsh__.env["XONSH_COLOR_STYLE"]
 
     if args.style is not None:
         if args.style not in color_style_names():
             print("Invalid style: {}".format(args.style))
             return
-        builtins.__xonsh_env__["XONSH_COLOR_STYLE"] = args.style
+        builtins.__xonsh__.env["XONSH_COLOR_STYLE"] = args.style
 
     color_map = color_style()
     akey = next(iter(color_map))
@@ -613,7 +608,7 @@ def _colors(args):
     else:
         s = _tok_colors(color_map, columns)
     print_color(s)
-    builtins.__xonsh_env__["XONSH_COLOR_STYLE"] = style_stash
+    builtins.__xonsh__.env["XONSH_COLOR_STYLE"] = style_stash
 
 
 def _tutorial(args):
@@ -622,6 +617,12 @@ def _tutorial(args):
     webbrowser.open("http://xon.sh/tutorial.html")
 
 
+def _web(args):
+    import subprocess
+
+    subprocess.run([sys.executable, "-m", "xonsh.webconfig"] + args.orig_args[1:])
+
+
 @functools.lru_cache(1)
 def _xonfig_create_parser():
     p = argparse.ArgumentParser(
@@ -634,7 +635,15 @@ def _xonfig_create_parser():
     info.add_argument(
         "--json", action="store_true", default=False, help="reports results as json"
     )
-    wiz = subp.add_parser("wizard", help="displays configuration information")
+    web = subp.add_parser("web", help="Launch configurator in browser.")
+    web.add_argument(
+        "--no-browser",
+        action="store_false",
+        dest="browser",
+        default=True,
+        help="don't open browser",
+    )
+    wiz = subp.add_parser("wizard", help="Launch configurator in terminal")
     wiz.add_argument(
         "--file", default=None, help="config file location, default=$XONSHRC"
     )
@@ -658,6 +667,7 @@ def _xonfig_create_parser():
 
 _XONFIG_MAIN_ACTIONS = {
     "info": _info,
+    "web": _web,
     "wizard": _wizard,
     "styles": _styles,
     "colors": _colors,
@@ -673,6 +683,7 @@ def xonfig_main(args=None):
         args.insert(0, "info")
     parser = _xonfig_create_parser()
     ns = parser.parse_args(args)
+    ns.orig_args = args
     if ns.action is None:  # apply default action
         ns = parser.parse_args(["info"] + args)
     return _XONFIG_MAIN_ACTIONS[ns.action](ns)
@@ -746,10 +757,10 @@ WELCOME_MSG = [
     ("{{INTENSE_BLACK}}", "<", "-"),
     "{{GREEN}}xonfig{{NO_COLOR}} tutorial    {{INTENSE_WHITE}}->    Launch the tutorial in "
     "the browser{{NO_COLOR}}",
-    "{{GREEN}}xonfig{{NO_COLOR}} wizard      {{INTENSE_WHITE}}->    Run the configuration "
-    "wizard and claim your shell {{NO_COLOR}}",
-    "{{INTENSE_BLACK}}(Note: Run the Wizard or create a {{RED}}~/.xonshrc{{INTENSE_BLACK}} file "
-    "to suppress the welcome screen)",
+    "{{GREEN}}xonfig{{NO_COLOR}} web         {{INTENSE_WHITE}}->    Run the configuration "
+    "tool in the browser and claim your shell {{NO_COLOR}}",
+    "{{INTENSE_BLACK}}(Note: Run the configurationn tool or create a "
+    "{{RED}}~/.xonshrc{{INTENSE_BLACK}} file to suppress the welcome screen)",
     "",
 ]
 
